AgentEnvAsyncLoop

Struct AgentEnvAsyncLoop 

pub struct AgentEnvAsyncLoop<BT: Backend, RLC: RLComponentsTypes> { /* private fields */ }
Available on crate feature rl only.
An asynchronous agent/environement interface.

Implementations

Source

impl<BT: Backend, RLC: RLComponentsTypes> AgentEnvAsyncLoop<BT, RLC>

pub fn new( env_init: RLC::EnvInit, agent: AsyncPolicy<RLC::Backend, <<RLC as RLComponentsTypes>::LearningAgent as PolicyLearner<<RLC as RLComponentsTypes>::Backend>>::InnerPolicy>, config: AsyncAgentEnvLoopConfig, transition_device: &Device<BT>, transition_sender: Option<Sender<TimeStep<BT, <RLC as RLComponentsTypes>::State, <RLC as RLComponentsTypes>::Action, <RLC as RLComponentsTypes>::ActionContext>>>, trajectory_sender: Option<Sender<Trajectory<BT, <RLC as RLComponentsTypes>::State, <RLC as RLComponentsTypes>::Action, <RLC as RLComponentsTypes>::ActionContext>>>, ) -> Self

Create a new asynchronous runner.

Arguments
  • env_init - A function returning an environment instance.
  • agent - An AsyncPolicy taking actions in the loop.
  • config - An AsyncAgentEnvLoopConfig.
  • transition_sender - Optional sender for transitions if you want to drive the requests from outside of the loop instance.
  • trajectory_sender - Optional sender for trajectories if you want to drive the requests from outside of the loop instance.
Returns

An async Agent/Environement loop.