pub struct RLResult<P> {
pub policy: P,
pub renderer: Box<dyn MetricsRenderer>,
}Available on crate feature
rl only.Expand description
The result of reinforcement learning, containing the final policy along with the renderer.
Fields
policy: PThe learned policy.
renderer: Box<dyn MetricsRenderer>The renderer that can be used for follow up training and evaluation.