A library for training neural networks using the burn crate.
Modules
- checkpoint
- The checkpoint module.
- logger
- The logger module.
- metric
- The metric module.
- renderer
- Renderer modules to display metrics and training information.
- train
- The trainer module.
Structs
- Agent
EnvAsync Loop rl - An asynchronous agent/environement interface.
- Agent
EnvBase Loop rl - A simple, synchronized agent/environement interface.
- Async
Agent EnvLoop Config rl - Configuration for an async agent/environment loop.
- Async
Processor Evaluation - Event processor for the model evaluation.
- Async
Processor Training - Event processor for the training process.
- Classification
Output - Simple classification output adapted for multiple metrics.
- Episode
Summary rl - Summary of an episode.
- Evaluation
Item - An evaluation item.
- Evaluator
- Evaluates a model on a specific dataset.
- Evaluator
Builder - Struct to configure and create an evaluator.
- File
Application Logger Installer - This struct is used to install a local file application logger to output logs to a given file path.
- Interrupter
- A handle that allows aborting the training/evaluation process early.
- Learner
- Learner struct encapsulating all components necessary to train a Neural Network model.
- Learner
Summary - Detailed training summary.
- Learner
Summary Config - Learning summary config.
- Learning
Checkpointer - Used to create, delete, or load checkpoints of the training process.
- Learning
Components Marker - Concrete type that implements the LearningComponentsTypes trait.
- Learning
Result - The result of a training, containing the model along with the renderer.
- Metric
Early Stopping Strategy - An early stopping strategy based on a metrics collected during training or validation.
- Metric
Entry - Contains the metric value at a given time.
- Metric
Summary - Contains the summary of recorded values for a given metric.
- Multi
Agent EnvLoop rl - An asynchronous runner for multiple agent/environement interfaces.
- Multi
Label Classification Output - Multi-label classification output adapted for multiple metrics.
- OffPolicy
Config rl - Parameters of an on policy training with multi environments and double-batching.
- OffPolicy
Strategy rl - Off-policy reinforcement learning strategy with multi-env experience collection and double-batching.
- RLCheckpointer
rl - Used to create, delete, or load checkpoints of the training process.
- RLComponents
rl - Struct to minimise parameters passed to RLStrategy::train.
- RLComponents
Marker rl - Concrete type that implements the RLComponentsTypes trait.
- RLResult
rl - The result of reinforcement learning, containing the final policy along with the renderer.
- RLTraining
rl - Structure to configure and launch reinforcement learning trainings.
- Regression
Output - Regression output adapted for the loss metric.
- Sequence
Output - Sequence prediction output adapted for multiple metrics.
- Summary
Metrics - Contains the summary of recorded metrics for the training and validation steps.
- Supervised
Training - Structure to configure and launch supervised learning trainings.
- Time
Step rl - A timestep debscribing an iteration of the state/decision process.
- Train
Output - A training output.
- Training
Components - Struct to minimise parameters passed to SupervisedLearningStrategy::train. These components are used during training.
- Training
Item - A learner item.
- Trajectory
rl - A trajectory, i.e. a list of ordered TimeStep.
Enums
- Evaluator
Event - Event happening during the evaluation process.
- Execution
Strategy - Describes where training runs.
- Learner
Event - Event happening during the training/validation process.
- Multi
Device Optim - Determine how the optimization is performed when training with multiple devices.
- RLStrategies
rl - The strategy for reinforcement learning.
- Stopping
Condition - The condition that early stopping strategies should follow.
- Training
Strategy - How should the learner run the learning for the model
Traits
- Agent
EnvLoop rl - Trait for a structure that implements an agent/environement interface.
- Agent
Metric Registration rl - Trait to fake variadic generics for train step metrics.
- Agent
Text Metric Registration rl - Trait to fake variadic generics for train step text metrics.
- Application
Logger Installer - This trait is used to install an application logger.
- Clone
Early Stopping Strategy - A helper trait to provide type-erased cloning.
- Early
Stopping Strategy - A strategy that checks if the training should be stopped.
- Episode
Metric Registration rl - Trait to fake variadic generics for episode metrics.
- Episode
Text Metric Registration rl - Trait to fake variadic generics for episode text metrics.
- Eval
Metric Registration - Trait to fake variadic generics.
- Eval
Text Metric Registration - Trait to fake variadic generics.
- Event
Processor Evaluation - Process events happening during evaluation.
- Event
Processor Training - Process events happening during training and validation.
- Inference
Step - Trait to be implemented for validating models.
- Item
Lazy - Items that are lazy are not ready to be processed by metrics.
- Learning
Components Types - Components used for a model to learn, grouped in one trait.
- Metric
Registration - Trait to fake variadic generics.
- RLComponents
Types rl - All components used by the reinforcement learning paradigm, grouped in one trait.
- RLStrategy
rl - Provides the
fitfunction for any learning strategy - Supervised
Learning Strategy - Provides the
fitfunction for any learning strategy - Text
Metric Registration - Trait to fake variadic generics.
- Train
Metric Registration rl - Trait to fake variadic generics for env step metrics.
- Train
Step - Trait to be implemented for models to be able to be trained.
- Train
Text Metric Registration rl - Trait to fake variadic generics for env step text metrics.
Type Aliases
- Custom
Learning Strategy - A reference to an implementation of SupervisedLearningStrategy.
- CustomRL
Strategy rl - A reference to an implementation of RLStrategy.
- Learner
Model Record - The record of the learner’s model.
- Learner
Optimizer Record - The record of the optimizer.
- Learner
Scheduler Record - The record of the LR scheduler.
- RLAgent
Record rl - The record of the learning agent.
- RLEvent
Processor Type rl - The event processor type for reinforcement learning.
- RLPolicy
Record rl - The record of the policy.
- Supervised
Training Event Processor - The event processor type for supervised learning.
- Train
Loader - A reference to the training split DataLoader.
- Training
Backend - The training backend.
- Training
Model - The model used for training.
- Valid
Loader - A reference to the validation split DataLoader.