pub struct RLComponents<RLC: RLComponentsTypes> {
pub num_steps: usize,
pub checkpoint: Option<usize>,
pub checkpointer: Option<RLCheckpointer<RLC>>,
pub grad_accumulation: Option<usize>,
pub interrupter: Interrupter,
pub event_processor: RLEventProcessorType<RLC>,
pub event_store: Arc<EventStoreClient>,
pub summary: Option<LearnerSummaryConfig>,
}Available on crate feature
rl only.Expand description
Struct to minimise parameters passed to RLStrategy::train.
Fields
num_steps: usizeThe total number of environment steps.
checkpoint: Option<usize>The step number from which to continue the training.
checkpointer: Option<RLCheckpointer<RLC>>A checkpointer used to load and save learning checkpoints.
grad_accumulation: Option<usize>Enables gradients accumulation.
interrupter: InterrupterAn Interupter that allows aborting the training/evaluation process early.
event_processor: RLEventProcessorType<RLC>An EventProcessor that processes events happening during training and evaluation.
event_store: Arc<EventStoreClient>A reference to an EventStoreClient.
summary: Option<LearnerSummaryConfig>Config for creating a summary of the learning